"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractPackageFile = void 0;
const logger_1 = require("../../../logger");
const regex_1 = require("../../../util/regex");
const bitbucket_tags_1 = require("../../datasource/bitbucket-tags");
const extract_1 = require("../dockerfile/extract");
const pipeRegex = (0, regex_1.regEx)(`^\\s*-\\s?pipe:\\s*'?"?([^\\s'"]+)'?"?\\s*$`);
const dockerImageRegex = (0, regex_1.regEx)(`^\\s*-?\\s?image:\\s*'?"?([^\\s'"]+)'?"?\\s*$`);
function extractPackageFile(content) {
    const deps = [];
    try {
        const lines = content.split(regex_1.newlineRegex);
        for (const line of lines) {
            const pipeMatch = pipeRegex.exec(line);
            if (pipeMatch) {
                const pipe = pipeMatch[1];
                if (pipe.startsWith('docker://')) {
                    const currentPipe = pipe.replace('docker://', '');
                    addDepAsDockerImage(deps, currentPipe);
                }
                else {
                    addDepAsBitbucketTag(deps, pipe);
                }
            }
            const dockerImageMatch = dockerImageRegex.exec(line);
            if (dockerImageMatch) {
                const currentFrom = dockerImageMatch[1];
                addDepAsDockerImage(deps, currentFrom);
            }
        }
    }
    catch (err) /* istanbul ignore next */ {
        logger_1.logger.warn({ err }, 'Error extracting Bitbucket Pipes dependencies');
    }
    if (!deps.length) {
        return null;
    }
    return { deps };
}
exports.extractPackageFile = extractPackageFile;
function addDepAsBitbucketTag(deps, pipe) {
    const [depName, currentValue] = pipe.split(':');
    const dep = {
        depName,
        currentValue,
        datasource: bitbucket_tags_1.BitbucketTagsDatasource.id,
    };
    dep.depType = 'bitbucket-tags';
    deps.push(dep);
}
function addDepAsDockerImage(deps, currentDockerImage) {
    const dep = (0, extract_1.getDep)(currentDockerImage);
    dep.depType = 'docker';
    deps.push(dep);
}
//# sourceMappingURL=extract.js.map